#!/usr/bin/env python

# Copyright 2018 Earth Sciences Department, BSC-CNS
#
# This file is part of HERMESv3_GR.
#
# HERMESv3_GR is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# HERMESv3_GR is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with HERMESv3_GR. If not, see <http://www.gnu.org/licenses/>.


from os import path
from setuptools import find_packages
from setuptools import setup

here = path.abspath(path.dirname(__file__))

# Get the version number from the relevant file
with open(path.join(here, 'VERSION')) as f:
    version = f.read().strip()

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='hermesv3_gr',
    license='GNU GPL v3',
    # platforms=['GNU/Linux Debian'],
    version=version,
    description='HERMESv3 Global/Regional',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Carles Tena Medina',
    author_email='carles.tena@bsc.es',
    url='https://earth.bsc.es/gitlab/es/hermesv3_gr',
    # download_url='https://earth.bsc.es/wiki/doku.php?id=tools:autosubmit',

    keywords=['emissions', 'cmaq', 'monarch', 'wrf-chem', 'atmospheric composition', 'air quality', 'earth science'],
    # setup_requires=['pyproj'],
    install_requires=[
        'numpy',
        'netCDF4>=1.3.1',
        'cdo>=1.3.4',
        'pandas',
        'geopandas',
        'pyproj',
        'configargparse',
        'cf_units>=1.1.3',
        # 'calendar',
        'ESMPy>=7.1.0',
        'holidays',
        'pytz',
        # 're',
        'timezonefinder',
        # 'unittest'
        'mpi4py'
    ],
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering :: Atmospheric Science"
    ],
    include_package_data=True,
    # package_data={'hermes_v3': [
    #     'autosubmit/config/files/autosubmit.conf',
    #     'autosubmit/config/files/expdef.conf',
    #     'autosubmit/database/data/autosubmit.sql',
    #     'README',
    #     'CHANGELOG',
    #     'VERSION',
    #     'LICENSE',
    #     'docs/autosubmit.pdf'
    # ]
    # },

    scripts=['bin/hermes_gr']
)
